14.113. cdist-type__prometheus_exporter(7) — cdist 4.8.1 documentation

# 14.113. cdist-type__prometheus_exporter(7)

## 14.113.1. NAME

cdist-type__prometheus_exporter - install some Prometheus exporters

## 14.113.2. DESCRIPTION

Install and configure some exporters to be used by the Prometheus monitoring system (https://prometheus.io/).

This type creates a daemontools-compatible service directory under /service/$__object_id. Daemontools (or something compatible) must be installed (in particular, the command svc must be executable).

This type installs and builds the latest version from git, using go get. A recent version of golang as well as build tools (make, g++, etc.) must be available.

Currently supported exporters:

- node
- blackbox
- ceph

## 14.113.3. REQUIRED PARAMETERS

None

## 14.113.4. OPTIONAL PARAMETERS

exporter
  Which exporter to install and configure. Default: $__object_id. Currently supported: node, blackbox, ceph.

## 14.113.5. BOOLEAN PARAMETERS

add-consul-service
  Add this exporter as a Consul service for automatic service discovery.

## 14.113.6. EXAMPLES

    __daemontools
    __golang_from_vendor --version 1.9  # required for prometheus and many exporters

    require="__daemontools __golang_from_vendor" __prometheus_exporter node

## 14.113.7. SEE ALSO

cdist-type__daemontools(7), cdist-type__golang_from_vendor(7), cdist-type__prometheus_server(7), Prometheus documentation: https://prometheus.io/docs/introduction/overview/

## 14.113.8. AUTHORS

Kamila Součková <kamila--@--ksp.sk>

## 14.113.9. COPYING

Copyright (C) 2017 Kamila Součková. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.